@@ -12,15 +12,25 @@ typedef struct {
 	gchar *message;
 } Revision;
 
+#include "cvs-plugin.h"
+
 typedef struct {
 	gchar *fname;
 	GList *revisions;
 	GList *rev_names;
 	GHashTable *rev_map;
+	CvsPlugin *plugin;
+
+	GtkWidget *rev_label;
+	GtkWidget *date_label;
+	GtkWidget *author_label;
+	GtkWidget *state_label;
+	GtkWidget *lines_label;
+	GtkWidget *msg_text_view;
 } LogHistory;
 
 
-LogHistory *log_create (const gchar *fpath);
+LogHistory *log_create (CvsPlugin *plugin, const gchar *fpath);
 void log_free (LogHistory *log);
 
 #endif // __PARSER_H__
