@@ -1,6 +1,6 @@
 /*
     GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2003 Marcus Bjurman
+    Copyright (C) 2001-2004 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
 #include "gnome-cmd-includes.h"
 #include "cap.h"
 #include "gnome-cmd-xfer.h"
-#include "gnome-cmd-file-funcs.h"
-#include "gnome-cmd-dir-funcs.h"
+#include "gnome-cmd-file.h"
+#include "gnome-cmd-dir.h"
 
 #define GNOME_CMD_CUTTED 1
 #define GNOME_CMD_COPIED 2
