@@ -25,6 +25,7 @@ typedef struct _GnomeCmdDataPrivate GnomeCmdDataPrivate;
 #include "gnome-cmd-app.h"
 #include "gnome-cmd-types.h"
 #include "gnome-cmd-con-list.h"
+#include "gnome-cmd-file-list.h"
 #include "filter.h"
 #include "history.h"
 
@@ -40,6 +41,8 @@ typedef enum
 	RIGHT_BUTTON_SELECTS
 } GnomeCmdRightMouseButtonMode;
 
+#define PATTERN_HISTORY_SIZE 10
+
 typedef struct
 {
 	GList *name_patterns;
@@ -143,6 +146,9 @@ gnome_cmd_data_get_color_mode            (void);
 void
 gnome_cmd_data_set_color_mode            (GnomeCmdColorMode mode);
 
+GnomeCmdColorTheme*
+gnome_cmd_data_get_custom_color_theme    (void);
+
 GnomeCmdColorTheme*
 gnome_cmd_data_get_current_color_theme   (void);
 
@@ -174,13 +180,16 @@ gboolean
 gnome_cmd_data_get_other_filter         (void);
 
 void
-gnome_cmd_data_set_position             (gint width, gint height);
+gnome_cmd_data_set_main_win_size        (gint width, gint height);
 
 void
-gnome_cmd_data_get_position             (gint *width, gint *height);
+gnome_cmd_data_get_main_win_size        (gint *width, gint *height);
 
 void
-gnome_cmd_data_save_position            (void);
+gnome_cmd_data_get_sort_params          (GnomeCmdFileList *fl, gint *col, gboolean *direction);
+
+void
+gnome_cmd_data_set_sort_params          (GnomeCmdFileList *fl, gint col, gboolean direction);
 
 void
 gnome_cmd_data_set_viewer               (const gchar *command);
@@ -314,8 +323,23 @@ gnome_cmd_data_get_use_ls_colors       (void);
 SearchDefaults *
 gnome_cmd_data_get_search_defaults     (void);
 
-GnomeCmdConFtp *
-gnome_cmd_data_get_quick_connect_server (void);
+const gchar *
+gnome_cmd_data_get_quick_connect_host  (void);
+
+const gchar *
+gnome_cmd_data_get_quick_connect_user  (void);
+
+gint
+gnome_cmd_data_get_quick_connect_port  (void);
+
+void
+gnome_cmd_data_set_quick_connect_host  (const gchar *value);
+
+void
+gnome_cmd_data_set_quick_connect_user  (const gchar *value);
+
+void
+gnome_cmd_data_set_quick_connect_port  (gint value);
 
 GnomeCmdBookmarkGroup *
 gnome_cmd_data_get_local_bookmarks      (void);
@@ -389,5 +413,19 @@ gnome_cmd_data_set_auto_load_plugins (GList *plugins);
 guint
 gnome_cmd_data_get_gui_update_rate (void);
 
+void
+gnome_cmd_data_set_main_win_pos (gint x, gint y);
+
+void
+gnome_cmd_data_get_main_win_pos (gint *x, gint *y);
+
+void
+gnome_cmd_data_set_backup_pattern (const gchar *value);
+
+const gchar *
+gnome_cmd_data_get_backup_pattern (void);
+
+GList *
+gnome_cmd_data_get_backup_pattern_list (void);
 
 #endif //__GNOME_CMD_DATA_H__
