@@ -71,6 +71,7 @@ gboolean state_is_alt (gint state);
 gboolean state_is_alt_shift (gint state);
 gboolean state_is_ctrl_alt (gint state);
 gboolean state_is_ctrl_shift (gint state);
+gboolean state_is_ctrl_alt_shift (gint state);
 
 GList *strings_to_uris (gchar *data);
 
@@ -110,4 +111,8 @@ gboolean create_dir_if_needed (const gchar *dpath);
 void edit_mimetypes (const gchar *mime_type, gboolean blocking);
 void fix_uri (GnomeVFSURI *uri);
 
+GList *patlist_new (const gchar *pattern_string);
+void patlist_free (GList *pattern_list);
+gboolean patlist_matches (GList *pattern_list, const gchar *s);
+
 #endif //__UTILS_H__
